@@ -3,6 +3,7 @@ from .channel import ChannelMixin
 from .handler import HandlerMixin
 from .message import MessageMixin
 from .self import SelfMixin
+from .socket import SocketMixin
 from .telemetry import TelemetryMixin
 from .user import UserMixin
 from .websocket import WebSocketMixin
@@ -18,3 +19,17 @@ class ApiMixin(
     TelemetryMixin,
 ):
     pass
+
+
+__all__ = [
+    "ApiMixin",
+    "AuthMixin",
+    "ChannelMixin",
+    "HandlerMixin",
+    "MessageMixin",
+    "SelfMixin",
+    "SocketMixin",
+    "TelemetryMixin",
+    "UserMixin",
+    "WebSocketMixin",
+]
